# azim

## Install

```ruby
pip install azim

# or 
uv add azim
```

## IM Services

### Open Source IM Services

- ✅ [Mattermost](https://github.com/mattermost/mattermost-server)
- ✅ [Matrix](https://github.com/matrix-org/matrix-synapse)
- ✅ [RocketChat](https://github.com/RocketChat/Rocket.Chat)
- ✅ [Zulip](https://github.com/zulip/zulip)

### 🇺🇸 EN IM Services

- ✅ [Telegram](https://telegram.org/)
- ✅ [Discord](https://discord.com/)
- ✅ [Slack](https://slack.com/)
- ✅ [Signal](https://signal.org/)
- ✅ [WhatsApp](https://www.whatsapp.com/)
- ✅ [Microsoft Teams](https://www.microsoft.com/en-us/microsoft-teams/group-chat-software)

### 🇨🇳 CN IM Services

- ✅ 飞书/Lark
- ✅ 企业微信
- ✅ 钉钉
